@@ -367,9 +367,7 @@ class InmantaPluginsImporter:
         return (
             (
                 file_name,
-                mod._get_fq_mod_name_for_py_file(
-                    file_name, plugin_dir, mod._meta["name"]
-                ),
+                mod._get_fq_mod_name_for_py_file(file_name, plugin_dir, mod.name),
             )
             for file_name in glob.iglob(
                 os.path.join(plugin_dir, "**", "*.py"), recursive=True
